
/******************Introductory Note*************************/

/*This technical application relates to module 4. It is based on firm-level data for some unspecified country. It examines the impact of SPS and TBT measures implemented by the European Union (14 countries, Luxembourg is missing) on this country firms exports. SPS and TBT data are extracted for the CEPII NTM dataset used in application 1. Firm data are available for various years but NTM data are cross-section data. We therefore focus on the year 2011 and run cross-section estimations.*/
/**********Preliminary Manipulations **********/

/*If you want to save the output of your session you must open a so-called log file */
log using application_3.log, replace /*it is in a text format*/

set matsize 4000

/*Before opening the dataset you may want to change the default directory that is the directory STATA will use unless another directory is specified. We created a folder called STATA_NTM (c:/ STATA_NTM) and copied all files that are needed to run the application (data files and do-files) into that folder. To change the default directory just run*/

cd c:/STATA_NTM/Application3

/*To open the dataset in STATA, the command use should be applied. Before running the estimations, we add some labels to the variables with the label var command. */

*Labels are self-explanatory.

use FIRMS.dta, clear
rename y year

* for many countries, NTMs in the CEPII dataset (version 2014) are for 2011. We decide to work with the 2011 exports of firms

keep if year == 2011

* drop incorrect HS product codes

gen l = length(hs)
tab l
drop if l != 6
drop l
rename hs hs6
rename d ccode_d

* drop domestic trade

drop if ccode_d == "XXX"
rename f firm
order firm year hs6 ccode_d 
sort firm year hs6 ccode_d 
count

* Focus on export flows to EU15

gen eu15_d = 1 if ccode_d == "AUT" | ccode_d == "BEL" | ccode_d == "DEU" | ccode_d =="DNK" | ccode_d == "ESP" | ccode_d == "FIN" | ccode_d =="FRA" | ccode_d == "GBR" | ccode_d == "GRC" | ccode_d == "IRL" | ccode_d == "ITA" | ccode_d == "NLD" | ccode_d == "PRT" | ccode_d == "SWE"
replace eu15_d = 0 if eu15_d == .
keep if eu15_d == 1
sort firm hs6 ccode_d
save temp_firmdata, replace

* Expand the dataset: create for each firm-product combination, all destinations (i.e. the potential number of destinations: 14 EU countries - LUX is missing)
* We first keep one observation per firm-hs6 code

keep firm hs6
bys firm hs6 : gen obs = _n
keep if obs == 1
drop obs 
codebook hs6, compact
codebook firm, compact
egen fp = group(firm hs6)

* for each fp, we create 14 observations: one for each potential EU destination

expand 14
bys fp : gen obs_expand = _n
gen ccode_d = "AUT" if obs_expand == 1
replace ccode_d = "DEU" if obs_expand == 2
replace ccode_d = "DNK" if obs_expand == 3
replace ccode_d = "FIN" if obs_expand == 4
replace ccode_d = "FRA" if obs_expand == 5
replace ccode_d = "GBR" if obs_expand == 6
replace ccode_d = "GRC" if obs_expand == 7
replace ccode_d = "IRL" if obs_expand == 8
replace ccode_d = "ITA" if obs_expand == 9
replace ccode_d = "NLD" if obs_expand == 10
replace ccode_d = "PRT" if obs_expand == 11
replace ccode_d = "SWE" if obs_expand == 12
replace ccode_d = "ESP" if obs_expand == 13
replace ccode_d = "BEL" if obs_expand == 14
drop obs_expand fp
sort firm hs6 ccode_d
save temp_firmdata_expand, replace

* Merge with temp_firmdata to get information on exported quantity and value for strictly positive flows
merge firm hs6 ccode_d using temp_firmdata
tab _merge
drop _merge
replace year = 2011 if year == .
replace v = 0 if v == .
replace q = 0 if q == .
save database, replace

erase temp_firmdata.dta
erase temp_firmdata_expand.dta


use Base_Mast_Oct2014.dta, clear

* Focus on SPS and TBTs
keep isor product numA numB PresA PresB
rename isor ccode_d
gen eu15_d = 1 if ccode_d == "AUT" | ccode_d == "BEL" | ccode_d == "DEU" | ccode_d == "DNK" | ccode_d == "ESP" | ccode_d == "FIN" | ccode_d == "FRA" | ccode_d == "GBR" | ccode_d == "GRC" | ccode_d == "IRL" | ccode_d == "ITA" | ccode_d == "NLD" | ccode_d == "PRT" | ccode_d =="SWE"
replace eu15_d = 0 if eu15_d == .
keep if eu15_d == 1
codebook ccode_d, compact
count
gen hs6 = string(product)
gen l = length(hs6)
tab l
replace hs6 = "0"+ hs6 if l == 5
drop product l
sort ccode_d hs6
save temp_NTM, replace

* Merge firm-level data with NTM data
use database, clear
sort ccode_d hs6
merge ccode_d hs6 using temp_NTM
tab _merge
drop if _merge == 2
drop _merge
replace numA = 0 if numA == .
replace numB = 0 if numB == .
replace PresA = 0 if PresA == .
replace PresB = 0 if PresB == .
* Define two variables for SPS and TBTs
* First variable: a simple dummy
gen Pres_SPSTBT = 1 if PresA == 1 | PresB == 1
replace Pres_SPSTBT = 0 if Pres_SPSTBT == .
* Second variable: the total number of SPS and TBTs at the product-importer level
gen num_SPSTBT = numA + numB
drop PresA PresB numA numB
save database, replace

erase temp_NTM.dta

/*********************Regressions**************************/

*Run the estimations using a simple dummy variable for NTMs

use database, clear
gen hs2 = substr(hs6, 1 , 2)

* Dependent variable: value of exports
* Regression #1: all flows
xi: poisson v Pres_SPSTBT i.hs2 i.ccode_d i.firm, difficult robust
eststo
* Regression #2: only strictly positive exported values
xi: poisson v Pres_SPSTBT i.hs2 i.ccode_d i.firm if v > 0, difficult robust
eststo
gen lnv=ln(v)
xi: reg lnv Pres_SPSTBT i.hs2 i.ccode_d i.firm if v > 0, robust
eststo

* Dependent variable: quantity of exports
* Regression #3: all flows
xi: poisson q Pres_SPSTBT i.hs2 i.ccode_d i.firm, difficult robust
eststo
* Regression #4: only strictly positive exported volumes
xi: poisson q Pres_SPSTBT i.hs2 i.ccode_d i.firm if q > 0, difficult robust
eststo
gen lnq=ln(q)
xi: reg lnq Pres_SPSTBT i.hs2 i.ccode_d i.firm if q > 0, robust
eststo

* Dependent variable: unit value of exports
* Regression #5: only strictly positive unit values
gen uv = v / q
xi: poisson uv Pres_SPSTBT i.hs2 i.ccode_d i.firm if uv > 0, difficult robust
eststo
gen lnuv=ln(uv)
xi: reg lnuv Pres_SPSTBT i.hs2 i.ccode_d i.firm if uv > 0, robust
eststo

esttab using NTM_REG_Firm_2.rtf, keep(Pres_SPSTBT) title(Presence of SPS/TBT) star(c 0.10 b 0.05 a 0.01) replace



/*Run the estimations controlling for the number of NTMs
We replicate the first set of estimations, but instead of using a simple dummy for NTMs, 
we now include the total number (in logs) of SPS and TBT measures notified by European importers on each HS 6-digit product. 
We therefore deal only with importer-product observations for which this number is strictly positive.*/ 

* Log number of SPS/TBT measures at the importer-product level
gen lnum_SPSTBT = ln(num_SPSTBT)

eststo clear

* Dependent variable: value of exports
* Regression #1: all flows
xi: poisson v lnum_SPSTBT i.hs2 i.ccode_d i.firm if num_SPSTBT > 0, difficult robust
eststo
* Regression #2: only strictly positive exported values
xi: poisson v lnum_SPSTBT i.hs2 i.ccode_d i.firm if num_SPSTBT > 0 & v > 0, difficult robust
eststo
xi: reg lnv lnum_SPSTBT i.hs2 i.ccode_d i.firm if num_SPSTBT > 0 & v > 0, robust
eststo

* Dependent variable: quantity of exports
* Regression #3: all flows
xi: poisson q lnum_SPSTBT i.hs2 i.ccode_d i.firm if num_SPSTBT > 0, difficult robust
eststo

* Regression #4: only strictly positive exported volumes
xi: poisson q lnum_SPSTBT i.hs2 i.ccode_d i.firm if num_SPSTBT > 0 & q >0, difficult robust
eststo
xi: reg lnq lnum_SPSTBT i.hs2 i.ccode_d i.firm if num_SPSTBT > 0 & q > 0, robust
eststo

* Dependent variable: unit value of exports
* Regression #5: only strictly positive unit values
xi: poisson uv lnum_SPSTBT i.hs2 i.ccode_d i.firm if num_SPSTBT > 0 & uv > 0, difficult robust
eststo
xi: reg lnuv lnum_SPSTBT i.hs2 i.ccode_d i.firm if num_SPSTBT > 0 & uv > 0, robust
eststo

esttab using NTM_REG_Firm_2.rtf, keep(lnum_SPSTBT) title(Number of SPS/TBT) star(c 0.10 b 0.05 a 0.01) append

log close
